Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type NilNotifier ¶
type NilNotifier struct{}
func NewNilNotifier ¶
func NewNilNotifier() *NilNotifier
func (*NilNotifier) Send ¶
func (nn *NilNotifier) Send(ctx context.Context, n Notification) error
type Notification ¶
type Notifier ¶
type Notifier interface {
Send(ctx context.Context, n Notification) error
}
Notifier defines the contract for sending alarms and metrics. Implementations of this interface are responsible for formatting and dispatching notifications to their respective backends. Implementations MUST be safe for concurrent use by multiple goroutines.
Click to show internal directories.
Click to hide internal directories.